==> ejc-sale-impl-3.0.0-20220511.020114-100-sources.jar: com/ejianc/business/sale/mapper/ProjectInfoMapper.java <==
package com.ejianc.business.sale.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.ejianc.business.sale.bean.InvoiceEntity;
import com.ejianc.business.sale.bean.ReceivablesEntity;
import com.ejianc.business.sale.bean.SignfreightEntity;
import org.apache.ibatis.annotations.Mapper;

import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import com.ejianc.business.sale.bean.ProjectInfoEntity;
import org.apache.ibatis.annotations.Param;

/**
 * 工程管理
 * 
 * @author generator
 * 
 */
@Mapper
public interface ProjectInfoMapper extends BaseCrudMapper<ProjectInfoEntity> {

    //主数据产品显示工程360
    IPage<ProjectInfoEntity> getSelect(IPage<ProjectInfoEntity> page,
                                       @Param(Constants.WRAPPER) QueryWrapper<ProjectInfoEntity> queryWrapper);

    //销售单显示收款管理360
    IPage<ReceivablesEntity> getReceivables(IPage<ReceivablesEntity> page,
                                          @Param(Constants.WRAPPER) QueryWrapper<ReceivablesEntity> queryWrapper);
    //销售单显示发票管理360
    IPage<InvoiceEntity> getInvoice(IPage<InvoiceEntity> page,
                                    @Param(Constants.WRAPPER) QueryWrapper<InvoiceEntity> queryWrapper);
    //发货管理显示运费确认单360
    IPage<SignfreightEntity> getSignfreight(IPage<SignfreightEntity> page,
                                        @Param(Constants.WRAPPER) QueryWrapper<SignfreightEntity> queryWrapper);

    
}

==> ejc-sale-impl-3.0.0-20220605.112218-140-sources.jar: com/ejianc/business/sale/mapper/ProjectInfoMapper.java <==
package com.ejianc.business.sale.mapper;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Constants;
import com.ejianc.business.sale.bean.*;
import org.apache.ibatis.annotations.Mapper;

import com.ejianc.framework.skeleton.template.BaseCrudMapper;
import org.apache.ibatis.annotations.Param;

/**
 * 工程管理
 * 
 * @author generator
 * 
 */
@Mapper
public interface ProjectInfoMapper extends BaseCrudMapper<ProjectInfoEntity> {

    //主数据产品显示工程360
    IPage<ProjectInfoEntity> getSelect(IPage<ProjectInfoEntity> page,
                                       @Param(Constants.WRAPPER) QueryWrapper<ProjectInfoEntity> queryWrapper);

    //销售单显示收款管理360
    IPage<ReceivablesEntity> getReceivables(IPage<ReceivablesEntity> page,
                                          @Param(Constants.WRAPPER) QueryWrapper<ReceivablesEntity> queryWrapper);
    //销售单显示发票管理360
    IPage<InvoiceEntity> getInvoice(IPage<InvoiceEntity> page,
                                    @Param(Constants.WRAPPER) QueryWrapper<InvoiceEntity> queryWrapper);
    //发货管理显示运费确认单360
    IPage<SignfreightEntity> getSignfreight(IPage<SignfreightEntity> page,
                                        @Param(Constants.WRAPPER) QueryWrapper<SignfreightEntity> queryWrapper);
    //运费确认单显示付款管理360
    IPage<PaymentEntity> getPayment(IPage<PaymentEntity> page,
                                        @Param(Constants.WRAPPER) QueryWrapper<PaymentEntity> queryWrapper);
    //运费确认单显示开票信息360
    IPage<OpeninvoiceEntity> getOpeninvoice(IPage<OpeninvoiceEntity> page,
                                    @Param(Constants.WRAPPER) QueryWrapper<OpeninvoiceEntity> queryWrapper);

    
}
